<?php

namespace Ems\Services;

use Ems\Repository\QuadroGeralVinculoRepository;
use Util\Environment;
use Ems\Services\EstruturaService;
use Ems\Repository\PeriodoRepository;
use Ems\Util\ArrayUtil;

class QuadroGeralVinculoService {
    /** @var QuadroGeralVinculoRepository */
    public $quadroGeralVinculoRepository;

    /** @var Environment */
    public $environment;

    /** @var EstruturaService */
    public $estruturaService;

    /** @var PeriodoRepository */
    public $periodoRepository;

    public function __construct(
        QuadroGeralVinculoRepository $quadroGeralVinculoRepository,
        Environment $environment,
        EstruturaService $estruturaService,
        PeriodoRepository $periodoRepository
    ) {
        $this->quadroGeralVinculoRepository = $quadroGeralVinculoRepository;
        $this->environment = $environment;
        $this->estruturaService = $estruturaService;
        $this->periodoRepository = $periodoRepository;
    }

    public function getQuadroGeralVinculo(
        int $nrEstrutura,
        int $nrPeriodo
    ) : array {
        $nrOrg = (int) $this->environment->getNrOrg();
        $nrOrgPadrao = (int) $this->environment->getNrOrgPadrao();

        $periodo = $this->periodoRepository->getPeriodo($nrOrg, $nrPeriodo);
        $dtFimPeriodo = explode(' ', $periodo['DTFINALAPURACAO'])[0];

        $nrEstruturasInferiores = null;

        if ($nrEstrutura !== -1) {
            $estruturas = $this->estruturaService->getTodasEstruturasInferiores($nrEstrutura, true);
            $nrEstruturasInferiores = ArrayUtil::toStringSQL($estruturas);
        }

        $params = [
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
            'P_NRESTRUTURAS'    => $nrEstruturasInferiores,
            'P_NRORG'           => $nrOrg,
            'P_DTFINALAPURACAO' => $dtFimPeriodo,
        ];

        $quadroGeralVinculo = $this->quadroGeralVinculoRepository->getQuadroGeralVinculo($params);;

        return $quadroGeralVinculo;
    }
}